package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcBudgetStaffMapper;
import com.ruoyi.oa.domain.CmcBudgetStaff;
import com.ruoyi.oa.service.ICmcBudgetStaffService;

/**
 * cmc人员预算Service业务层处理
 * 
 * @author cmc
 * @date 2024-03-22
 */
@Service
public class CmcBudgetStaffServiceImpl implements ICmcBudgetStaffService 
{
    @Autowired
    private CmcBudgetStaffMapper cmcBudgetStaffMapper;

    /**
     * 查询cmc人员预算
     * 
     * @param budgetId cmc预算id
     * @return cmc人员预算
     */
    @Override
    public List<CmcBudgetStaff> selectCmcBudgetStaffByBudgetId(String budgetId)
    {
        return cmcBudgetStaffMapper.selectCmcBudgetStaffByBudgetId(budgetId);
    }

    /**
     * 查询cmc人员预算列表
     * 
     * @param cmcBudgetStaff cmc人员预算
     * @return cmc人员预算
     */
    @Override
    public List<CmcBudgetStaff> selectCmcBudgetStaffList(CmcBudgetStaff cmcBudgetStaff)
    {
        return cmcBudgetStaffMapper.selectCmcBudgetStaffList(cmcBudgetStaff);
    }

    /**
     * 新增cmc人员预算
     * 
     * @param cmcBudgetStaff cmc人员预算
     * @return 结果
     */
    @Override
    public int insertCmcBudgetStaff(CmcBudgetStaff cmcBudgetStaff)
    {
        return cmcBudgetStaffMapper.insertCmcBudgetStaff(cmcBudgetStaff);
    }

    /**
     * 修改cmc人员预算
     * 
     * @param cmcBudgetStaff cmc人员预算
     * @return 结果
     */
    @Override
    public int updateCmcBudgetStaff(CmcBudgetStaff cmcBudgetStaff)
    {
        return cmcBudgetStaffMapper.updateCmcBudgetStaff(cmcBudgetStaff);
    }

    /**
     * 批量删除cmc人员预算
     * 
     * @param budgetIds 需要删除的cmc人员预算主键
     * @return 结果
     */
    @Override
    public int deleteCmcBudgetStaffByBudgetIds(String[] budgetIds)
    {
        return cmcBudgetStaffMapper.deleteCmcBudgetStaffByBudgetIds(budgetIds);
    }

    /**
     * 删除cmc人员预算信息
     * 
     * @param budgetId cmc人员预算主键
     * @return 结果
     */
    @Override
    public int deleteCmcBudgetStaffByBudgetId(String budgetId)
    {
        return cmcBudgetStaffMapper.deleteCmcBudgetStaffByBudgetId(budgetId);
    }
}
