package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcBudgetStaff;
import com.ruoyi.oa.service.ICmcBudgetStaffService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc人员预算Controller
 * 
 * @author cmc
 * @date 2024-03-22
 */
@RestController
@RequestMapping("/oa/budgetStaff")
public class CmcBudgetStaffController extends BaseController
{
    @Autowired
    private ICmcBudgetStaffService cmcBudgetStaffService;

    /**
     * 查询cmc人员预算列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcBudgetStaff cmcBudgetStaff)
    {
        startPage();
        List<CmcBudgetStaff> list = cmcBudgetStaffService.selectCmcBudgetStaffList(cmcBudgetStaff);
        return getDataTable(list);
    }

    /**
     * 导出cmc人员预算列表
     */
    @Log(title = "cmc人员预算", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcBudgetStaff cmcBudgetStaff)
    {
        List<CmcBudgetStaff> list = cmcBudgetStaffService.selectCmcBudgetStaffList(cmcBudgetStaff);
        ExcelUtil<CmcBudgetStaff> util = new ExcelUtil<CmcBudgetStaff>(CmcBudgetStaff.class);
        util.exportExcel(response, list, "cmc人员预算数据");
    }

    /**
     * 获取cmc人员预算详细信息
     */
    @GetMapping(value = "/{budgetId}")
    public AjaxResult getInfo(@PathVariable("budgetId") String budgetId)
    {
        return success(cmcBudgetStaffService.selectCmcBudgetStaffByBudgetId(budgetId));
    }

    /**
     * 新增cmc人员预算
     */
    @Log(title = "cmc人员预算", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcBudgetStaff cmcBudgetStaff)
    {
        return toAjax(cmcBudgetStaffService.insertCmcBudgetStaff(cmcBudgetStaff));
    }

    /**
     * 修改cmc人员预算
     */
    @Log(title = "cmc人员预算", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcBudgetStaff cmcBudgetStaff)
    {
        return toAjax(cmcBudgetStaffService.updateCmcBudgetStaff(cmcBudgetStaff));
    }

    /**
     * 删除cmc人员预算
     */
    @Log(title = "cmc人员预算", businessType = BusinessType.DELETE)
	@DeleteMapping("/{budgetIds}")
    public AjaxResult remove(@PathVariable String[] budgetIds)
    {
        return success(cmcBudgetStaffService.deleteCmcBudgetStaffByBudgetIds(budgetIds));
    }
}
